==> clean_android_design-0.1.0.tar.gz: lib/src/structure/list/hover_list_item.dart <==
import 'package:clean_android_design/clean_android_design.dart';
import 'package:flutter/foundation.dart';
import 'package:flutter/material.dart';

class HoverListItem extends StatefulWidget implements ISelectableListItem {
  final Widget Function(bool? hover)? leadingBuilder;
  final Widget Function(bool? hover)? trailingBuilder;
  final Widget Function(bool? hover)? titleBuilder;
  final Widget Function(bool? hover)? descriptionBuilder;
  final bool? isFirst;
  final bool? isLast;
  final bool? isSelected;
  final GestureTapCallback? onTap;
  final bool Function()? onTapList;
  final void Function()? onLongTapList;
  final HighlightController? highlightController;

  const HoverListItem({
    Key? key,
    this.onTap,
    this.onTapList,
    this.onLongTapList,
    this.highlightController,
    this.leadingBuilder,
    this.trailingBuilder,
    this.titleBuilder,
    this.descriptionBuilder,
  })  : this.isFirst = null,
        this.isLast = null,
        this.isSelected = null,
        super(key: key);

  const HoverListItem._copy({
    Key? key,
    this.isFirst,
    this.isLast,
    this.isSelected,
    this.onTap,
    this.onTapList,
    this.onLongTapList,
    this.highlightController,
    this.leadingBuilder,
    this.trailingBuilder,
    this.titleBuilder,
    this.descriptionBuilder,
  }) : super(key: key);

  @override
  _HoverListItemState createState() => _HoverListItemState();

  @override
  IListItem copyWithPosition({bool? isFirst, bool? isLast}) {
    return HoverListItem._copy(
      descriptionBuilder: descriptionBuilder,
      highlightController: highlightController,
      isFirst: isFirst,
      isLast: isLast,
      isSelected: isSelected,
      key: key,
      leadingBuilder: leadingBuilder,
      onLongTapList: onLongTapList,
      onTap: onTap,
      onTapList: onTapList,
      titleBuilder: titleBuilder,
      trailingBuilder: trailingBuilder,
    );
  }

  @override
  IListItem copyWithSelection(
      {bool? isSelected,
      bool Function()? onTapList,
      void Function()? onLongTapList}) {
    return HoverListItem._copy(
      descriptionBuilder: descriptionBuilder,
      highlightController: highlightController,
      isFirst: isFirst,
      isLast: isLast,
      isSelected: isSelected,
      key: key,
      leadingBuilder: leadingBuilder,
      onLongTapList: onLongTapList,
      onTap: onTap,
      onTapList: onTapList,
      titleBuilder: titleBuilder,
      trailingBuilder: trailingBuilder,
    );
  }
}

class _HoverListItemState extends State<HoverListItem> {
  bool? hover;

  @override
  void initState() {
    super.initState();

    hover = !kIsWeb;
  }

  @override
  Widget build(BuildContext context) {
    return DefaultListItem(
      onHover: kIsWeb
          ? (value) {
              setState(() => hover = value);
            }
          : null,
      description: widget.descriptionBuilder?.call(hover),
      leading: widget.leadingBuilder?.call(hover),
      title: widget.titleBuilder?.call(hover),
      trailing: widget.trailingBuilder?.call(hover),
      onTap: widget.onTap,
      highlightController: widget.highlightController,
    )
        .copyWithSelection(
          isSelected: widget.isSelected,
          onLongTapList: widget.onLongTapList,
          onTapList: widget.onTapList,
        )
        .copyWithPosition(
          isFirst: widget.isFirst,
          isLast: widget.isLast,
        );
  }
}

==> clean_android_design-0.1.7.tar.gz: lib/src/structure/list/hover_list_item.dart <==
import 'package:clean_android_design/clean_android_design.dart';
import 'package:flutter/foundation.dart';
import 'package:flutter/material.dart';

class HoverListItem extends StatefulWidget implements ISelectableListItem {
  final Widget Function(bool hover)? leadingBuilder;
  final Widget Function(bool hover)? trailingBuilder;
  final Widget Function(bool hover)? titleBuilder;
  final Widget Function(bool hover)? descriptionBuilder;
  final bool? isFirst;
  final bool? isLast;
  final bool? isSelected;
  final GestureTapCallback? onTap;
  final bool Function()? onTapList;
  final void Function()? onLongTapList;
  final HighlightController? highlightController;

  const HoverListItem({
    Key? key,
    this.onTap,
    this.onTapList,
    this.onLongTapList,
    this.highlightController,
    this.leadingBuilder,
    this.trailingBuilder,
    this.titleBuilder,
    this.descriptionBuilder,
  })  : this.isFirst = null,
        this.isLast = null,
        this.isSelected = null,
        super(key: key);

  const HoverListItem._copy({
    Key? key,
    this.isFirst,
    this.isLast,
    this.isSelected,
    this.onTap,
    this.onTapList,
    this.onLongTapList,
    this.highlightController,
    this.leadingBuilder,
    this.trailingBuilder,
    this.titleBuilder,
    this.descriptionBuilder,
  }) : super(key: key);

  @override
  _HoverListItemState createState() => _HoverListItemState();

  @override
  IListItem copyWithPosition({bool? isFirst, bool? isLast}) {
    return HoverListItem._copy(
      descriptionBuilder: descriptionBuilder,
      highlightController: highlightController,
      isFirst: isFirst,
      isLast: isLast,
      isSelected: isSelected,
      key: key,
      leadingBuilder: leadingBuilder,
      onLongTapList: onLongTapList,
      onTap: onTap,
      onTapList: onTapList,
      titleBuilder: titleBuilder,
      trailingBuilder: trailingBuilder,
    );
  }

  @override
  IListItem copyWithSelection(
      {bool? isSelected,
      bool Function()? onTapList,
      void Function()? onLongTapList}) {
    return HoverListItem._copy(
      descriptionBuilder: descriptionBuilder,
      highlightController: highlightController,
      isFirst: isFirst,
      isLast: isLast,
      isSelected: isSelected,
      key: key,
      leadingBuilder: leadingBuilder,
      onLongTapList: onLongTapList,
      onTap: onTap,
      onTapList: onTapList,
      titleBuilder: titleBuilder,
      trailingBuilder: trailingBuilder,
    );
  }
}

class _HoverListItemState extends State<HoverListItem> {
  late bool hover;

  @override
  void initState() {
    super.initState();

    hover = !kIsWeb;
  }

  @override
  Widget build(BuildContext context) {
    return DefaultListItem(
      onHover: kIsWeb
          ? (value) {
              setState(() => hover = value);
            }
          : null,
      description: widget.descriptionBuilder?.call(hover),
      leading: widget.leadingBuilder?.call(hover),
      title: widget.titleBuilder?.call(hover),
      trailing: widget.trailingBuilder?.call(hover),
      onTap: widget.onTap,
      highlightController: widget.highlightController,
    )
        .copyWithSelection(
          isSelected: widget.isSelected,
          onLongTapList: widget.onLongTapList,
          onTapList: widget.onTapList,
        )
        .copyWithPosition(
          isFirst: widget.isFirst,
          isLast: widget.isLast,
        );
  }
}
